# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_network.proto\x12#oak9.tython.azure.microsoft_network\x1a\x13shared/shared.proto\"\xc2\x1a\n\x11Microsoft_Network\x12\x94\x01\n5application_gateway_web_application_firewall_policies\x18\x01 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network.ApplicationGatewayWebApplicationFirewallPolicies\x12\x63\n\x1b\x61pplication_security_groups\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.ApplicationSecurityGroups\x12L\n\x0f\x61zure_firewalls\x18\x03 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_network.AzureFirewalls\x12H\n\rbastion_hosts\x18\x04 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.BastionHosts\x12\x45\n\x0b\x63onnections\x18\x05 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.Connections\x12Q\n\x12\x63ustom_ip_prefixes\x18\x06 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network.CustomIpPrefixes\x12U\n\x14\x64\x64os_custom_policies\x18\x07 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network.DdosCustomPolicies\x12W\n\x15\x64\x64os_protection_plans\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network.DdosProtectionPlans\x12T\n\x13\x64scp_configurations\x18\t \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network.DscpConfigurations\x12Y\n\x16\x65xpress_route_circuits\x18\n \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network.ExpressRouteCircuits\x12j\n\x1f\x65xpress_route_cross_connections\x18\x0b \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.ExpressRouteCrossConnections\x12Y\n\x16\x65xpress_route_gateways\x18\x0c \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network.ExpressRouteGateways\x12S\n\x13\x65xpress_route_ports\x18\r \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.ExpressRoutePorts\x12J\n\x0eip_allocations\x18\x0e \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_network.IpAllocations\x12@\n\tip_groups\x18\x0f \x03(\x0b\x32-.oak9.tython.azure.microsoft_network.IpGroups\x12Y\n\x16local_network_gateways\x18\x10 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network.LocalNetworkGateways\x12\x46\n\x0cnat_gateways\x18\x11 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.NatGateways\x12R\n\x12network_interfaces\x18\x12 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.NetworkInterfaces\x12N\n\x10network_profiles\x18\x13 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_network.NetworkProfiles\x12\x61\n\x1anetwork_virtual_appliances\x18\x14 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.NetworkVirtualAppliances\x12N\n\x10network_watchers\x18\x15 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_network.NetworkWatchers\x12L\n\x0fp2svpn_gateways\x18\x16 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_network.P2svpnGateways\x12S\n\x13public_ip_addresses\x18\x17 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.PublicIPAddresses\x12Q\n\x12public_ip_prefixes\x18\x18 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network.PublicIPPrefixes\x12H\n\rroute_filters\x18\x19 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.RouteFilters\x12k\n route_filters_route_filter_rules\x18\x1a \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.RouteFiltersRouteFilterRules\x12\x61\n\x1asecurity_partner_providers\x18\x1b \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.SecurityPartnerProviders\x12_\n\x19service_endpoint_policies\x18\x1c \x03(\x0b\x32<.oak9.tython.azure.microsoft_network.ServiceEndpointPolicies\x12\xa3\x01\n=service_endpoint_policies_service_endpoint_policy_definitions\x18\x1d \x03(\x0b\x32\\.oak9.tython.azure.microsoft_network.ServiceEndpointPoliciesServiceEndpointPolicyDefinitions\x12\x46\n\x0cvirtual_hubs\x18\x1e \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.VirtualHubs\x12]\n\x18virtual_network_gateways\x18\x1f \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.VirtualNetworkGateways\x12U\n\x14virtual_network_taps\x18  \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network.VirtualNetworkTaps\x12L\n\x0fvirtual_routers\x18! \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_network.VirtualRouters\x12\x46\n\x0cvirtual_wans\x18\" \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.VirtualWans\x12\x46\n\x0cvpn_gateways\x18# \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.VpnGateways\x12\x64\n\x1cvpn_gateways_vpn_connections\x18$ \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.VpnGatewaysVpnConnections\x12_\n\x19vpn_server_configurations\x18% \x03(\x0b\x32<.oak9.tython.azure.microsoft_network.VpnServerConfigurations\x12@\n\tvpn_sites\x18& \x03(\x0b\x32-.oak9.tython.azure.microsoft_network.VpnSites\"\xac\x05\n\x08VpnSites\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x45\n\x04tags\x18\x04 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network.VpnSites.TagsEntry\x12\x13\n\x0bvirtual_wan\x18\x05 \x01(\t\x12P\n\x11\x64\x65vice_properties\x18\x06 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.DeviceProperties\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x10\n\x08site_key\x18\x08 \x01(\t\x12H\n\raddress_space\x18\t \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.AddressSpace\x12H\n\x0e\x62gp_properties\x18\n \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_network.BgpSettings\x12\x18\n\x10is_security_site\x18\x0b \x01(\x08\x12H\n\x0evpn_site_links\x18\x0c \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.VpnSiteLink\x12N\n\x0bo365_policy\x18\r \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.O365PolicyProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x14O365PolicyProperties\x12_\n\x14\x62reak_out_categories\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network.O365BreakOutCategoryPolicies\"P\n\x1cO365BreakOutCategoryPolicies\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\x12\x10\n\x08optimize\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\x08\"\xe7\x01\n\x0bVpnSiteLink\x12W\n\x0flink_properties\x18\x01 \x01(\x0b\x32>.oak9.tython.azure.microsoft_network.VpnLinkProviderProperties\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x03 \x01(\t\x12O\n\x0e\x62gp_properties\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network.VpnLinkBgpSettings\x12\x0c\n\x04name\x18\x05 \x01(\t\">\n\x12VpnLinkBgpSettings\x12\x0b\n\x03\x61sn\x18\x01 \x01(\x05\x12\x1b\n\x13\x62gp_peering_address\x18\x02 \x01(\t\"S\n\x19VpnLinkProviderProperties\x12\x1a\n\x12link_provider_name\x18\x01 \x01(\t\x12\x1a\n\x12link_speed_in_mbps\x18\x02 \x01(\x05\"[\n\x10\x44\x65viceProperties\x12\x15\n\rdevice_vendor\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x02 \x01(\t\x12\x1a\n\x12link_speed_in_mbps\x18\x03 \x01(\x05\"\xd6\x08\n\x17VpnServerConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network.VpnServerConfigurations.TagsEntry\x12\x15\n\rvpn_protocols\x18\x05 \x03(\t\x12 \n\x18vpn_authentication_types\x18\x06 \x03(\t\x12r\n\x1cvpn_client_root_certificates\x18\x07 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network.VpnServerConfigVpnClientRootCertificate\x12x\n\x1fvpn_client_revoked_certificates\x18\x08 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network.VpnServerConfigVpnClientRevokedCertificate\x12x\n\x1fradius_server_root_certificates\x18\t \x03(\x0b\x32O.oak9.tython.azure.microsoft_network.VpnServerConfigRadiusServerRootCertificate\x12x\n\x1fradius_client_root_certificates\x18\n \x03(\x0b\x32O.oak9.tython.azure.microsoft_network.VpnServerConfigRadiusClientRootCertificate\x12S\n\x19vpn_client_ipsec_policies\x18\x0b \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12\x1d\n\x15radius_server_address\x18\x0c \x01(\t\x12\x1c\n\x14radius_server_secret\x18\r \x01(\t\x12I\n\x0eradius_servers\x18\x0e \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.RadiusServer\x12g\n\x1d\x61\x61\x64_authentication_parameters\x18\x0f \x01(\x0b\x32@.oak9.tython.azure.microsoft_network.AadAuthenticationParameters\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x1b\x41\x61\x64\x41uthenticationParameters\x12\x12\n\naad_tenant\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x61\x64_audience\x18\x02 \x01(\t\x12\x12\n\naad_issuer\x18\x03 \x01(\t\"N\n*VpnServerConfigRadiusClientRootCertificate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nthumbprint\x18\x02 \x01(\t\"T\n*VpnServerConfigRadiusServerRootCertificate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10public_cert_data\x18\x02 \x01(\t\"N\n*VpnServerConfigVpnClientRevokedCertificate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nthumbprint\x18\x02 \x01(\t\"Q\n\'VpnServerConfigVpnClientRootCertificate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10public_cert_data\x18\x02 \x01(\t\"\xa4\x06\n\x19VpnGatewaysVpnConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fremote_vpn_site\x18\x03 \x01(\t\x12\x16\n\x0erouting_weight\x18\x04 \x01(\x05\x12\x1b\n\x13\x64pd_timeout_seconds\x18\x05 \x01(\x05\x12\x19\n\x11\x63onnection_status\x18\x06 \x01(\t\x12$\n\x1cvpn_connection_protocol_type\x18\x07 \x01(\t\x12\x1c\n\x14\x63onnection_bandwidth\x18\x08 \x01(\x05\x12\x12\n\nshared_key\x18\t \x01(\t\x12\x12\n\nenable_bgp\x18\n \x01(\x08\x12*\n\"use_policy_based_traffic_selectors\x18\x0b \x01(\x08\x12H\n\x0eipsec_policies\x18\x0c \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12]\n\x19traffic_selector_policies\x18\r \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.TrafficSelectorPolicy\x12\x1c\n\x14\x65nable_rate_limiting\x18\x0e \x01(\x08\x12 \n\x18\x65nable_internet_security\x18\x0f \x01(\x08\x12\"\n\x1ause_local_azure_ip_address\x18\x10 \x01(\x08\x12X\n\x14vpn_link_connections\x18\x11 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.VpnSiteLinkConnection\x12X\n\x15routing_configuration\x18\x12 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.RoutingConfiguration\"\xbb\x02\n\x13VpnGatewaysNatRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12Q\n\x11internal_mappings\x18\x05 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VpnNatRuleMapping\x12Q\n\x11\x65xternal_mappings\x18\x06 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VpnNatRuleMapping\x12\x1b\n\x13ip_configuration_id\x18\x07 \x01(\t\"\xf0\x04\n\x0bVpnGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.VpnGateways.TagsEntry\x12\x13\n\x0bvirtual_hub\x18\x05 \x01(\t\x12G\n\x0b\x63onnections\x18\x06 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_network.VpnConnection\x12\x46\n\x0c\x62gp_settings\x18\x07 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_network.BgpSettings\x12\x1e\n\x16vpn_gateway_scale_unit\x18\x08 \x01(\x05\x12&\n\x1eis_routing_preference_internet\x18\t \x01(\x08\x12I\n\tnat_rules\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VpnGatewayNatRule\x12X\n\x16vpn_gateways_nat_rules\x18\x0b \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network.VpnGatewaysNatRules\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n\x11VpnGatewayNatRule\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12Q\n\x11internal_mappings\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VpnNatRuleMapping\x12Q\n\x11\x65xternal_mappings\x18\x04 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VpnNatRuleMapping\x12\x1b\n\x13ip_configuration_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"*\n\x11VpnNatRuleMapping\x12\x15\n\raddress_space\x18\x01 \x01(\t\"\xdf\x05\n\rVpnConnection\x12\x17\n\x0fremote_vpn_site\x18\x01 \x01(\t\x12\x16\n\x0erouting_weight\x18\x02 \x01(\x05\x12\x1b\n\x13\x64pd_timeout_seconds\x18\x03 \x01(\x05\x12\x19\n\x11\x63onnection_status\x18\x04 \x01(\t\x12$\n\x1cvpn_connection_protocol_type\x18\x05 \x01(\t\x12\x1c\n\x14\x63onnection_bandwidth\x18\x06 \x01(\x05\x12\x12\n\nshared_key\x18\x07 \x01(\t\x12\x12\n\nenable_bgp\x18\x08 \x01(\x08\x12*\n\"use_policy_based_traffic_selectors\x18\t \x01(\x08\x12H\n\x0eipsec_policies\x18\n \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12]\n\x19traffic_selector_policies\x18\x0b \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.TrafficSelectorPolicy\x12\x1c\n\x14\x65nable_rate_limiting\x18\x0c \x01(\x08\x12 \n\x18\x65nable_internet_security\x18\r \x01(\x08\x12\"\n\x1ause_local_azure_ip_address\x18\x0e \x01(\x08\x12X\n\x14vpn_link_connections\x18\x0f \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.VpnSiteLinkConnection\x12X\n\x15routing_configuration\x18\x10 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.RoutingConfiguration\x12\x0c\n\x04name\x18\x11 \x01(\t\"\xea\x03\n\x15VpnSiteLinkConnection\x12\x15\n\rvpn_site_link\x18\x01 \x01(\t\x12\x16\n\x0erouting_weight\x18\x02 \x01(\x05\x12 \n\x18vpn_link_connection_mode\x18\x03 \x01(\t\x12\x19\n\x11\x63onnection_status\x18\x04 \x01(\t\x12$\n\x1cvpn_connection_protocol_type\x18\x05 \x01(\t\x12\x1c\n\x14\x63onnection_bandwidth\x18\x06 \x01(\x05\x12\x12\n\nshared_key\x18\x07 \x01(\t\x12\x12\n\nenable_bgp\x18\x08 \x01(\x08\x12*\n\"use_policy_based_traffic_selectors\x18\t \x01(\x08\x12H\n\x0eipsec_policies\x18\n \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12\x1c\n\x14\x65nable_rate_limiting\x18\x0b \x01(\x08\x12\"\n\x1ause_local_azure_ip_address\x18\x0c \x01(\x08\x12\x19\n\x11ingress_nat_rules\x18\r \x03(\t\x12\x18\n\x10\x65gress_nat_rules\x18\x0e \x03(\t\x12\x0c\n\x04name\x18\x0f \x01(\t\"\x82\x03\n\x0bVirtualWans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.VirtualWans.TagsEntry\x12\x1e\n\x16\x64isable_vpn_encryption\x18\x05 \x01(\x08\x12&\n\x1e\x61llow_branch_to_branch_traffic\x18\x06 \x01(\x08\x12\"\n\x1a\x61llow_vnet_to_vnet_traffic\x18\x07 \x01(\x08\x12)\n!office365_local_breakout_category\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x16VirtualRoutersPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08peer_asn\x18\x03 \x01(\x05\x12\x0f\n\x07peer_ip\x18\x04 \x01(\t\"\xa9\x03\n\x0eVirtualRouters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12K\n\x04tags\x18\x04 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.VirtualRouters.TagsEntry\x12\x1a\n\x12virtual_router_asn\x18\x05 \x01(\x05\x12\x1a\n\x12virtual_router_ips\x18\x06 \x03(\t\x12\x15\n\rhosted_subnet\x18\x07 \x01(\t\x12\x16\n\x0ehosted_gateway\x18\x08 \x01(\t\x12]\n\x18virtual_routers_peerings\x18\t \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.VirtualRoutersPeerings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x02\n\x12VirtualNetworkTaps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12O\n\x04tags\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.VirtualNetworkTaps.TagsEntry\x12\x36\n.destination_network_interface_ip_configuration\x18\x05 \x01(\t\x12<\n4destination_load_balancer_front_end_ip_configuration\x18\x06 \x01(\t\x12\x18\n\x10\x64\x65stination_port\x18\x07 \x01(\x05\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf8\x07\n\x16VirtualNetworkGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12S\n\x04tags\x18\x04 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network.VirtualNetworkGateways.TagsEntry\x12\x64\n\x11ip_configurations\x18\x05 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network.VirtualNetworkGatewayIPConfiguration\x12\x14\n\x0cgateway_type\x18\x06 \x01(\t\x12\x10\n\x08vpn_type\x18\x07 \x01(\t\x12\x1e\n\x16vpn_gateway_generation\x18\x08 \x01(\t\x12\x12\n\nenable_bgp\x18\t \x01(\x08\x12!\n\x19\x65nable_private_ip_address\x18\n \x01(\x08\x12\x15\n\ractive_active\x18\x0b \x01(\x08\x12\x1c\n\x14gateway_default_site\x18\x0c \x01(\t\x12J\n\x03sku\x18\r \x01(\x0b\x32=.oak9.tython.azure.microsoft_network.VirtualNetworkGatewaySku\x12]\n\x18vpn_client_configuration\x18\x0e \x01(\x0b\x32;.oak9.tython.azure.microsoft_network.VpnClientConfiguration\x12\x46\n\x0c\x62gp_settings\x18\x0f \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_network.BgpSettings\x12H\n\rcustom_routes\x18\x10 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.AddressSpace\x12\x1d\n\x15\x65nable_dns_forwarding\x18\x11 \x01(\x08\x12+\n#v_net_extended_location_resource_id\x18\x12 \x01(\t\x12`\n!virtual_network_extended_location\x18\x13 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x05\n\x16VpnClientConfiguration\x12R\n\x17vpn_client_address_pool\x18\x01 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.AddressSpace\x12\x63\n\x1cvpn_client_root_certificates\x18\x02 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.VpnClientRootCertificate\x12i\n\x1fvpn_client_revoked_certificates\x18\x03 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network.VpnClientRevokedCertificate\x12\x1c\n\x14vpn_client_protocols\x18\x04 \x03(\t\x12 \n\x18vpn_authentication_types\x18\x05 \x03(\t\x12S\n\x19vpn_client_ipsec_policies\x18\x06 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12\x1d\n\x15radius_server_address\x18\x07 \x01(\t\x12\x1c\n\x14radius_server_secret\x18\x08 \x01(\t\x12I\n\x0eradius_servers\x18\t \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.RadiusServer\x12\x12\n\naad_tenant\x18\n \x01(\t\x12\x14\n\x0c\x61\x61\x64_audience\x18\x0b \x01(\t\x12\x12\n\naad_issuer\x18\x0c \x01(\t\"h\n\x0cRadiusServer\x12\x1d\n\x15radius_server_address\x18\x01 \x01(\t\x12\x1b\n\x13radius_server_score\x18\x02 \x01(\x05\x12\x1c\n\x14radius_server_secret\x18\x03 \x01(\t\"?\n\x1bVpnClientRevokedCertificate\x12\x12\n\nthumbprint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"B\n\x18VpnClientRootCertificate\x12\x18\n\x10public_cert_data\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n\x18VirtualNetworkGatewaySku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"\x85\x01\n$VirtualNetworkGatewayIPConfiguration\x12$\n\x1cprivate_ip_allocation_method\x18\x01 \x01(\t\x12\x0e\n\x06subnet\x18\x02 \x01(\t\x12\x19\n\x11public_ip_address\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xc5\x01\n\x16VirtualHubsRouteTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x46\n\x06routes\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VirtualHubRouteV2\x12\x1c\n\x14\x61ttached_connections\x18\x04 \x03(\t\"\xb4\x02\n\x1bVirtualHubsIpConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x04 \x01(\t\x12;\n\x06subnet\x18\x05 \x01(\x0b\x32+.oak9.tython.azure.microsoft_network.Subnet\x12O\n\x11public_ip_address\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_network.PublicIPAddress\"\xba\x05\n\x0fPublicIPAddress\x12\x10\n\x08location\x18\x01 \x01(\t\x12L\n\x04tags\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.PublicIPAddress.TagsEntry\x12P\n\x11\x65xtended_location\x18\x03 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x12\x44\n\x03sku\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network.PublicIPAddressSku\x12#\n\x1bpublic_ip_allocation_method\x18\x05 \x01(\t\x12!\n\x19public_ip_address_version\x18\x06 \x01(\t\x12U\n\x0c\x64ns_settings\x18\x07 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network.PublicIPAddressDnsSettings\x12H\n\rddos_settings\x18\x08 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.DdosSettings\x12;\n\x07ip_tags\x18\t \x03(\x0b\x32*.oak9.tython.azure.microsoft_network.IpTag\x12\x12\n\nip_address\x18\n \x01(\t\x12\x18\n\x10public_ip_prefix\x18\x0b \x01(\t\x12\x1f\n\x17idle_timeout_in_minutes\x18\x0c \x01(\x05\x12\r\n\x05zones\x18\r \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x03\n\x06Subnet\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\t\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x02 \x03(\t\x12\x1e\n\x16network_security_group\x18\x03 \x01(\t\x12\x13\n\x0broute_table\x18\x04 \x01(\t\x12\x13\n\x0bnat_gateway\x18\x05 \x01(\t\x12_\n\x11service_endpoints\x18\x06 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_network.ServiceEndpointPropertiesFormat\x12!\n\x19service_endpoint_policies\x18\x07 \x03(\t\x12\x16\n\x0eip_allocations\x18\x08 \x03(\t\x12\x44\n\x0b\x64\x65legations\x18\t \x03(\x0b\x32/.oak9.tython.azure.microsoft_network.Delegation\x12)\n!private_endpoint_network_policies\x18\n \x01(\t\x12-\n%private_link_service_network_policies\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\"0\n\nDelegation\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x1fServiceEndpointPropertiesFormat\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tlocations\x18\x02 \x03(\t\"\xea\x02\n\'VirtualHubsHubVirtualNetworkConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16remote_virtual_network\x18\x03 \x01(\t\x12(\n allow_hub_to_remote_vnet_transit\x18\x04 \x01(\x08\x12\x32\n*allow_remote_vnet_to_use_hub_vnet_gateways\x18\x05 \x01(\x08\x12 \n\x18\x65nable_internet_security\x18\x06 \x01(\x08\x12X\n\x15routing_configuration\x18\x07 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.RoutingConfiguration\"\xb1\x01\n\x19VirtualHubsHubRouteTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\x06routes\x18\x03 \x03(\x0b\x32-.oak9.tython.azure.microsoft_network.HubRoute\x12\x0e\n\x06labels\x18\x04 \x03(\t\"q\n\x08HubRoute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_type\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65stinations\x18\x03 \x03(\t\x12\x15\n\rnext_hop_type\x18\x04 \x01(\t\x12\x10\n\x08next_hop\x18\x05 \x01(\t\"\x85\x01\n\x19VirtualHubsBgpConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08peer_asn\x18\x03 \x01(\x05\x12\x0f\n\x07peer_ip\x18\x04 \x01(\t\"\x85\n\n\x0bVirtualHubs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.VirtualHubs.TagsEntry\x12\x13\n\x0bvirtual_wan\x18\x05 \x01(\t\x12\x13\n\x0bvpn_gateway\x18\x06 \x01(\t\x12\x18\n\x10p2_s_vpn_gateway\x18\x07 \x01(\t\x12\x1d\n\x15\x65xpress_route_gateway\x18\x08 \x01(\t\x12\x16\n\x0e\x61zure_firewall\x18\t \x01(\t\x12!\n\x19security_partner_provider\x18\n \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x0b \x01(\t\x12N\n\x0broute_table\x18\x0c \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.VirtualHubRouteTable\x12\x1e\n\x16security_provider_name\x18\r \x01(\t\x12`\n\x1bvirtual_hub_route_table_v2s\x18\x0e \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.VirtualHubRouteTableV2\x12\x0b\n\x03sku\x18\x0f \x01(\t\x12\x15\n\rrouting_state\x18\x10 \x01(\t\x12\x1a\n\x12virtual_router_asn\x18\x11 \x01(\x05\x12\x1a\n\x12virtual_router_ips\x18\x12 \x03(\t\x12&\n\x1e\x61llow_branch_to_branch_traffic\x18\x13 \x01(\x08\x12\x65\n\x1dvirtual_hubs_hub_route_tables\x18\x14 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.VirtualHubsHubRouteTables\x12h\n\x1evirtual_hubs_ip_configurations\x18\x15 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network.VirtualHubsIpConfigurations\x12\x64\n\x1cvirtual_hubs_bgp_connections\x18\x16 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.VirtualHubsBgpConnections\x12^\n\x19virtual_hubs_route_tables\x18\x17 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.VirtualHubsRouteTables\x12\x82\x01\n,virtual_hubs_hub_virtual_network_connections\x18\x18 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network.VirtualHubsHubVirtualNetworkConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16VirtualHubRouteTableV2\x12\x46\n\x06routes\x18\x01 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network.VirtualHubRouteV2\x12\x1c\n\x14\x61ttached_connections\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"m\n\x11VirtualHubRouteV2\x12\x18\n\x10\x64\x65stination_type\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65stinations\x18\x02 \x03(\t\x12\x15\n\rnext_hop_type\x18\x03 \x01(\t\x12\x11\n\tnext_hops\x18\x04 \x03(\t\"\\\n\x14VirtualHubRouteTable\x12\x44\n\x06routes\x18\x01 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_network.VirtualHubRoute\"H\n\x0fVirtualHubRoute\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x01 \x03(\t\x12\x1b\n\x13next_hop_ip_address\x18\x02 \x01(\t\"\xc1\x01\n7ServiceEndpointPoliciesServiceEndpointPolicyDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x19\n\x11service_resources\x18\x05 \x03(\t\"\xe8\x02\n\x17ServiceEndpointPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network.ServiceEndpointPolicies.TagsEntry\x12q\n#service_endpoint_policy_definitions\x18\x05 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_network.ServiceEndpointPolicyDefinition\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"p\n\x1fServiceEndpointPolicyDefinition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x19\n\x11service_resources\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xac\x02\n\x18SecurityPartnerProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12U\n\x04tags\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.SecurityPartnerProviders.TagsEntry\x12\x1e\n\x16security_provider_name\x18\x05 \x01(\t\x12\x13\n\x0bvirtual_hub\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x1cRouteFiltersRouteFilterRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x03 \x01(\t\x12\x1e\n\x16route_filter_rule_type\x18\x04 \x01(\t\x12\x13\n\x0b\x63ommunities\x18\x05 \x03(\t\x12\x10\n\x08location\x18\x06 \x01(\t\"\xa4\x02\n\x0cRouteFilters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12I\n\x04tags\x18\x04 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.RouteFilters.TagsEntry\x12\x43\n\x05rules\x18\x05 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_network.RouteFilterRule\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x0fRouteFilterRule\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\t\x12\x1e\n\x16route_filter_rule_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63ommunities\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\"\x9e\x04\n\x10PublicIPPrefixes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12M\n\x04tags\x18\x04 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.PublicIPPrefixes.TagsEntry\x12P\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x12\x43\n\x03sku\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_network.PublicIPPrefixSku\x12!\n\x19public_ip_address_version\x18\x07 \x01(\t\x12;\n\x07ip_tags\x18\x08 \x03(\x0b\x32*.oak9.tython.azure.microsoft_network.IpTag\x12\x15\n\rprefix_length\x18\t \x01(\x05\x12\x18\n\x10\x63ustom_ip_prefix\x18\n \x01(\t\x12\r\n\x05zones\x18\x0b \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x11PublicIPPrefixSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"\x85\x06\n\x11PublicIPAddresses\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12N\n\x04tags\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network.PublicIPAddresses.TagsEntry\x12P\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x12\x44\n\x03sku\x18\x06 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network.PublicIPAddressSku\x12#\n\x1bpublic_ip_allocation_method\x18\x07 \x01(\t\x12!\n\x19public_ip_address_version\x18\x08 \x01(\t\x12U\n\x0c\x64ns_settings\x18\t \x01(\x0b\x32?.oak9.tython.azure.microsoft_network.PublicIPAddressDnsSettings\x12H\n\rddos_settings\x18\n \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.DdosSettings\x12;\n\x07ip_tags\x18\x0b \x03(\x0b\x32*.oak9.tython.azure.microsoft_network.IpTag\x12\x12\n\nip_address\x18\x0c \x01(\t\x12\x18\n\x10public_ip_prefix\x18\r \x01(\t\x12\x1f\n\x17idle_timeout_in_minutes\x18\x0e \x01(\x05\x12\r\n\x05zones\x18\x0f \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x05IpTag\x12\x13\n\x0bip_tag_type\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"]\n\x0c\x44\x64osSettings\x12\x1a\n\x12\x64\x64os_custom_policy\x18\x01 \x01(\t\x12\x1b\n\x13protection_coverage\x18\x02 \x01(\t\x12\x14\n\x0cprotected_ip\x18\x03 \x01(\x08\"[\n\x1aPublicIPAddressDnsSettings\x12\x19\n\x11\x64omain_name_label\x18\x01 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x02 \x01(\t\x12\x14\n\x0creverse_fqdn\x18\x03 \x01(\t\"0\n\x12PublicIPAddressSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"\xe7\x03\n\x0eP2svpnGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12K\n\x04tags\x18\x04 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.P2svpnGateways.TagsEntry\x12\x13\n\x0bvirtual_hub\x18\x05 \x01(\t\x12g\n\x1ep2_s_connection_configurations\x18\x06 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.P2SConnectionConfiguration\x12\x1e\n\x16vpn_gateway_scale_unit\x18\x07 \x01(\x05\x12 \n\x18vpn_server_configuration\x18\x08 \x01(\t\x12\x1a\n\x12\x63ustom_dns_servers\x18\t \x03(\t\x12&\n\x1eis_routing_preference_internet\x18\n \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x1aP2SConnectionConfiguration\x12R\n\x17vpn_client_address_pool\x18\x01 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.AddressSpace\x12X\n\x15routing_configuration\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.RoutingConfiguration\x12 \n\x18\x65nable_internet_security\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x83\x03\n\x1dNetworkWatchersPacketCaptures\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12#\n\x1b\x62ytes_to_capture_per_packet\x18\x04 \x01(\x05\x12\x1f\n\x17total_bytes_per_session\x18\x05 \x01(\x05\x12\x1d\n\x15time_limit_in_seconds\x18\x06 \x01(\x05\x12[\n\x10storage_location\x18\x07 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network.PacketCaptureStorageLocation\x12I\n\x07\x66ilters\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network.PacketCaptureFilter\"\x85\x01\n\x13PacketCaptureFilter\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x18\n\x10local_ip_address\x18\x02 \x01(\t\x12\x19\n\x11remote_ip_address\x18\x03 \x01(\t\x12\x12\n\nlocal_port\x18\x04 \x01(\t\x12\x13\n\x0bremote_port\x18\x05 \x01(\t\"[\n\x1cPacketCaptureStorageLocation\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x14\n\x0cstorage_path\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"\xc5\x04\n\x17NetworkWatchersFlowLogs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network.NetworkWatchersFlowLogs.TagsEntry\x12\x1a\n\x12target_resource_id\x18\x05 \x01(\t\x12\x12\n\nstorage_id\x18\x06 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12X\n\x10retention_policy\x18\x08 \x01(\x0b\x32>.oak9.tython.azure.microsoft_network.RetentionPolicyParameters\x12L\n\x06\x66ormat\x18\t \x01(\x0b\x32<.oak9.tython.azure.microsoft_network.FlowLogFormatParameters\x12\x65\n\x1c\x66low_analytics_configuration\x18\n \x01(\x0b\x32?.oak9.tython.azure.microsoft_network.TrafficAnalyticsProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n\x1aTrafficAnalyticsProperties\x12\x82\x01\n,network_watcher_flow_analytics_configuration\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network.TrafficAnalyticsConfigurationProperties\"\xad\x01\n\'TrafficAnalyticsConfigurationProperties\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\x18\n\x10workspace_region\x18\x03 \x01(\t\x12\x1d\n\x15workspace_resource_id\x18\x04 \x01(\t\x12\"\n\x1atraffic_analytics_interval\x18\x05 \x01(\x05\"8\n\x17\x46lowLogFormatParameters\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\":\n\x19RetentionPolicyParameters\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\xd8\x06\n!NetworkWatchersConnectionMonitors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12^\n\x04tags\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network.NetworkWatchersConnectionMonitors.TagsEntry\x12L\n\x06source\x18\x05 \x01(\x0b\x32<.oak9.tython.azure.microsoft_network.ConnectionMonitorSource\x12V\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network.ConnectionMonitorDestination\x12\x12\n\nauto_start\x18\x07 \x01(\x08\x12&\n\x1emonitoring_interval_in_seconds\x18\x08 \x01(\x05\x12Q\n\tendpoints\x18\t \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpoint\x12\x64\n\x13test_configurations\x18\n \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorTestConfiguration\x12T\n\x0btest_groups\x18\x0b \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.ConnectionMonitorTestGroup\x12M\n\x07outputs\x18\x0c \x03(\x0b\x32<.oak9.tython.azure.microsoft_network.ConnectionMonitorOutput\x12\r\n\x05notes\x18\r \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x17\x43onnectionMonitorOutput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x63\n\x12workspace_settings\x18\x02 \x01(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorWorkspaceSettings\"C\n\"ConnectionMonitorWorkspaceSettings\x12\x1d\n\x15workspace_resource_id\x18\x01 \x01(\t\"\x7f\n\x1a\x43onnectionMonitorTestGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x12\x1b\n\x13test_configurations\x18\x03 \x03(\t\x12\x0f\n\x07sources\x18\x04 \x03(\t\x12\x14\n\x0c\x64\x65stinations\x18\x05 \x03(\t\"\x8e\x04\n\"ConnectionMonitorTestConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x12test_frequency_sec\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x1c\n\x14preferred_ip_version\x18\x04 \x01(\t\x12\x63\n\x12http_configuration\x18\x05 \x01(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorHttpConfiguration\x12\x61\n\x11tcp_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network.ConnectionMonitorTcpConfiguration\x12\x63\n\x12icmp_configuration\x18\x07 \x01(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorIcmpConfiguration\x12\x61\n\x11success_threshold\x18\x08 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network.ConnectionMonitorSuccessThreshold\"^\n!ConnectionMonitorSuccessThreshold\x12\x1d\n\x15\x63hecks_failed_percent\x18\x01 \x01(\x05\x12\x1a\n\x12round_trip_time_ms\x18\x02 \x01(\x01\"A\n\"ConnectionMonitorIcmpConfiguration\x12\x1b\n\x13\x64isable_trace_route\x18\x01 \x01(\x08\"q\n!ConnectionMonitorTcpConfiguration\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x1b\n\x13\x64isable_trace_route\x18\x02 \x01(\x08\x12!\n\x19\x64\x65stination_port_behavior\x18\x03 \x01(\t\"\xd3\x01\n\"ConnectionMonitorHttpConfiguration\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12H\n\x0frequest_headers\x18\x04 \x03(\x0b\x32/.oak9.tython.azure.microsoft_network.HTTPHeader\x12 \n\x18valid_status_code_ranges\x18\x05 \x03(\t\x12\x15\n\rprefer_http_s\x18\x06 \x01(\x08\")\n\nHTTPHeader\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9f\x02\n\x19\x43onnectionMonitorEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12T\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpointFilter\x12R\n\x05scope\x18\x06 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpointScope\x12\x16\n\x0e\x63overage_level\x18\x07 \x01(\t\"\xd4\x01\n\x1e\x43onnectionMonitorEndpointScope\x12X\n\x07include\x18\x01 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpointScopeItem\x12X\n\x07\x65xclude\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpointScopeItem\"5\n\"ConnectionMonitorEndpointScopeItem\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x88\x01\n\x1f\x43onnectionMonitorEndpointFilter\x12\x0c\n\x04type\x18\x01 \x01(\t\x12W\n\x05items\x18\x02 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network.ConnectionMonitorEndpointFilterItem\"D\n#ConnectionMonitorEndpointFilterItem\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"R\n\x1c\x43onnectionMonitorDestination\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"<\n\x17\x43onnectionMonitorSource\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\xab\x04\n\x0fNetworkWatchers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12L\n\x04tags\x18\x04 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.NetworkWatchers.TagsEntry\x12`\n\x1anetwork_watchers_flow_logs\x18\x05 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network.NetworkWatchersFlowLogs\x12t\n$network_watchers_connection_monitors\x18\x06 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network.NetworkWatchersConnectionMonitors\x12l\n network_watchers_packet_captures\x18\x07 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network.NetworkWatchersPacketCaptures\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n-NetworkVirtualAppliancesVirtualApplianceSites\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x03 \x01(\t\x12S\n\x0bo365_policy\x18\x04 \x01(\x0b\x32>.oak9.tython.azure.microsoft_network.Office365PolicyProperties\"x\n\x19Office365PolicyProperties\x12[\n\x14\x62reak_out_categories\x18\x01 \x01(\x0b\x32=.oak9.tython.azure.microsoft_network.BreakOutCategoryPolicies\"L\n\x18\x42reakOutCategoryPolicies\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\x12\x10\n\x08optimize\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\x08\"\xbf\x01\n,NetworkVirtualAppliancesInboundSecurityRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\x05rules\x18\x03 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network.InboundSecurityRules\"g\n\x14InboundSecurityRules\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x1d\n\x15source_address_prefix\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65stination_port_range\x18\x03 \x01(\x05\"\xe1\x06\n\x18NetworkVirtualAppliances\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12U\n\x04tags\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.NetworkVirtualAppliances.TagsEntry\x12S\n\x07nva_sku\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_network.VirtualApplianceSkuProperties\x12&\n\x1e\x62oot_strap_configuration_blobs\x18\x06 \x03(\t\x12\x13\n\x0bvirtual_hub\x18\x07 \x01(\t\x12&\n\x1e\x63loud_init_configuration_blobs\x18\x08 \x03(\t\x12 \n\x18\x63loud_init_configuration\x18\t \x01(\t\x12\x1d\n\x15virtual_appliance_asn\x18\n \x01(\x05\x12M\n\x08identity\x18\x0b \x01(\x0b\x32;.oak9.tython.azure.microsoft_network.ManagedServiceIdentity\x12\x8c\x01\n1network_virtual_appliances_inbound_security_rules\x18\x0c \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network.NetworkVirtualAppliancesInboundSecurityRules\x12\x8e\x01\n2network_virtual_appliances_virtual_appliance_sites\x18\r \x03(\x0b\x32R.oak9.tython.azure.microsoft_network.NetworkVirtualAppliancesVirtualApplianceSites\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x1dVirtualApplianceSkuProperties\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x1a\n\x12\x62undled_scale_unit\x18\x02 \x01(\t\x12\x1c\n\x14market_place_version\x18\x03 \x01(\t\"\xe6\x02\n\x0fNetworkProfiles\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12L\n\x04tags\x18\x04 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network.NetworkProfiles.TagsEntry\x12\x7f\n*container_network_interface_configurations\x18\x05 \x03(\x0b\x32K.oak9.tython.azure.microsoft_network.ContainerNetworkInterfaceConfiguration\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x01\n&ContainerNetworkInterfaceConfiguration\x12V\n\x11ip_configurations\x18\x01 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.IPConfigurationProfile\x12$\n\x1c\x63ontainer_network_interfaces\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"6\n\x16IPConfigurationProfile\x12\x0e\n\x06subnet\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\"NetworkInterfacesTapConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13virtual_network_tap\x18\x03 \x01(\t\"\xd1\x05\n\x11NetworkInterfaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12N\n\x04tags\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network.NetworkInterfaces.TagsEntry\x12P\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x12\x1e\n\x16network_security_group\x18\x06 \x01(\t\x12_\n\x11ip_configurations\x18\x07 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_network.NetworkInterfaceIPConfiguration\x12V\n\x0c\x64ns_settings\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network.NetworkInterfaceDnsSettings\x12%\n\x1d\x65nable_accelerated_networking\x18\t \x01(\x08\x12\x1c\n\x14\x65nable_ip_forwarding\x18\n \x01(\x08\x12v\n%network_interfaces_tap_configurations\x18\x0b \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.NetworkInterfacesTapConfigurations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x1bNetworkInterfaceDnsSettings\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\x12\x1f\n\x17internal_dns_name_label\x18\x02 \x01(\t\"\x9d\x03\n\x1fNetworkInterfaceIPConfiguration\x12\x1c\n\x14virtual_network_taps\x18\x01 \x03(\t\x12\x31\n)application_gateway_backend_address_pools\x18\x02 \x03(\t\x12+\n#load_balancer_backend_address_pools\x18\x03 \x03(\t\x12\'\n\x1fload_balancer_inbound_nat_rules\x18\x04 \x03(\t\x12\x1a\n\x12private_ip_address\x18\x05 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x06 \x01(\t\x12\"\n\x1aprivate_ip_address_version\x18\x07 \x01(\t\x12\x0e\n\x06subnet\x18\x08 \x01(\t\x12\x0f\n\x07primary\x18\t \x01(\x08\x12\x19\n\x11public_ip_address\x18\n \x01(\t\x12#\n\x1b\x61pplication_security_groups\x18\x0b \x03(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\"\x87\x03\n\x0bNatGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.NatGateways.TagsEntry\x12?\n\x03sku\x18\x05 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_network.NatGatewaySku\x12\x1f\n\x17idle_timeout_in_minutes\x18\x06 \x01(\x05\x12\x1b\n\x13public_ip_addresses\x18\x07 \x03(\t\x12\x1a\n\x12public_ip_prefixes\x18\x08 \x03(\t\x12\r\n\x05zones\x18\t \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1d\n\rNatGatewaySku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb9\x03\n\x14LocalNetworkGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12Q\n\x04tags\x18\x04 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network.LocalNetworkGateways.TagsEntry\x12V\n\x1blocal_network_address_space\x18\x05 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_network.AddressSpace\x12\x1a\n\x12gateway_ip_address\x18\x06 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x07 \x01(\t\x12\x46\n\x0c\x62gp_settings\x18\x08 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_network.BgpSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x01\n\x0b\x42gpSettings\x12\x0b\n\x03\x61sn\x18\x01 \x01(\x05\x12\x1b\n\x13\x62gp_peering_address\x18\x02 \x01(\t\x12\x13\n\x0bpeer_weight\x18\x03 \x01(\x05\x12\x64\n\x15\x62gp_peering_addresses\x18\x04 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network.IPConfigurationBgpPeeringAddress\"_\n IPConfigurationBgpPeeringAddress\x12\x1a\n\x12ipconfiguration_id\x18\x01 \x01(\t\x12\x1f\n\x17\x63ustom_bgp_ip_addresses\x18\x02 \x03(\t\"(\n\x0c\x41\x64\x64ressSpace\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x01 \x03(\t\"\xed\x01\n\x08IpGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x45\n\x04tags\x18\x04 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network.IpGroups.TagsEntry\x12\x14\n\x0cip_addresses\x18\x05 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x03\n\rIpAllocations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12J\n\x04tags\x18\x04 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network.IpAllocations.TagsEntry\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x15\n\rprefix_length\x18\x07 \x01(\x05\x12\x13\n\x0bprefix_type\x18\x08 \x01(\t\x12\x1a\n\x12ipam_allocation_id\x18\t \x01(\t\x12_\n\x0f\x61llocation_tags\x18\n \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network.IpAllocations.AllocationTagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13\x41llocationTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x03\n\x11\x45xpressRoutePorts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12N\n\x04tags\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network.ExpressRoutePorts.TagsEntry\x12\x18\n\x10peering_location\x18\x05 \x01(\t\x12\x19\n\x11\x62\x61ndwidth_in_gbps\x18\x06 \x01(\x05\x12\x15\n\rencapsulation\x18\x07 \x01(\t\x12\x44\n\x05links\x18\x08 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExpressRouteLink\x12M\n\x08identity\x18\t \x01(\x0b\x32;.oak9.tython.azure.microsoft_network.ManagedServiceIdentity\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12y\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x10\x45xpressRouteLink\x12\x13\n\x0b\x61\x64min_state\x18\x01 \x01(\t\x12Y\n\x0emac_sec_config\x18\x02 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network.ExpressRouteLinkMacSecConfig\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x7f\n\x1c\x45xpressRouteLinkMacSecConfig\x12\x1d\n\x15\x63kn_secret_identifier\x18\x01 \x01(\t\x12\x1d\n\x15\x63\x61k_secret_identifier\x18\x02 \x01(\t\x12\x0e\n\x06\x63ipher\x18\x03 \x01(\t\x12\x11\n\tsci_state\x18\x04 \x01(\t\"\xf0\x02\n+ExpressRouteGatewaysExpressRouteConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x1d\x65xpress_route_circuit_peering\x18\x03 \x01(\t\x12\x19\n\x11\x61uthorization_key\x18\x04 \x01(\t\x12\x16\n\x0erouting_weight\x18\x05 \x01(\x05\x12 \n\x18\x65nable_internet_security\x18\x06 \x01(\x08\x12$\n\x1c\x65xpress_route_gateway_bypass\x18\x07 \x01(\x08\x12X\n\x15routing_configuration\x18\x08 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.RoutingConfiguration\"\xd7\x01\n\x14RoutingConfiguration\x12\x1e\n\x16\x61ssociated_route_table\x18\x01 \x01(\t\x12Z\n\x17propagated_route_tables\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.PropagatedRouteTable\x12\x43\n\x0bvnet_routes\x18\x03 \x01(\x0b\x32..oak9.tython.azure.microsoft_network.VnetRoute\"T\n\tVnetRoute\x12G\n\rstatic_routes\x18\x01 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.StaticRoute\"R\n\x0bStaticRoute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x02 \x03(\t\x12\x1b\n\x13next_hop_ip_address\x18\x03 \x01(\t\"3\n\x14PropagatedRouteTable\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\"\x8d\x04\n\x14\x45xpressRouteGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12Q\n\x04tags\x18\x04 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network.ExpressRouteGateways.TagsEntry\x12z\n\x18\x61uto_scale_configuration\x18\x05 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network.ExpressRouteGatewayPropertiesAutoScaleConfiguration\x12\x13\n\x0bvirtual_hub\x18\x06 \x01(\t\x12\x8a\x01\n0express_route_gateways_express_route_connections\x18\x07 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network.ExpressRouteGatewaysExpressRouteConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x01\n3ExpressRouteGatewayPropertiesAutoScaleConfiguration\x12n\n\x06\x62ounds\x18\x01 \x01(\x0b\x32^.oak9.tython.azure.microsoft_network.ExpressRouteGatewayPropertiesAutoScaleConfigurationBounds\"U\n9ExpressRouteGatewayPropertiesAutoScaleConfigurationBounds\x12\x0b\n\x03min\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"\x84\x04\n$ExpressRouteCrossConnectionsPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cpeering_type\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x10\n\x08peer_asn\x18\x05 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x06 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x07 \x01(\t\x12\x12\n\nshared_key\x18\x08 \x01(\t\x12\x0f\n\x07vlan_id\x18\t \x01(\x05\x12g\n\x18microsoft_peering_config\x18\n \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeeringConfig\x12\x1c\n\x14gateway_manager_etag\x18\x0b \x01(\t\x12\x66\n\x13ipv6_peering_config\x18\x0c \x01(\x0b\x32I.oak9.tython.azure.microsoft_network.Ipv6ExpressRouteCircuitPeeringConfig\"\xc3\x04\n\x1c\x45xpressRouteCrossConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12Y\n\x04tags\x18\x04 \x03(\x0b\x32K.oak9.tython.azure.microsoft_network.ExpressRouteCrossConnections.TagsEntry\x12\x1d\n\x15\x65xpress_route_circuit\x18\x05 \x01(\t\x12+\n#service_provider_provisioning_state\x18\x06 \x01(\t\x12\x1e\n\x16service_provider_notes\x18\x07 \x01(\t\x12Y\n\x08peerings\x18\x08 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.ExpressRouteCrossConnectionPeering\x12{\n(express_route_cross_connections_peerings\x18\t \x03(\x0b\x32I.oak9.tython.azure.microsoft_network.ExpressRouteCrossConnectionsPeerings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x03\n\"ExpressRouteCrossConnectionPeering\x12\x14\n\x0cpeering_type\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x10\n\x08peer_asn\x18\x03 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x04 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x05 \x01(\t\x12\x12\n\nshared_key\x18\x06 \x01(\t\x12\x0f\n\x07vlan_id\x18\x07 \x01(\x05\x12g\n\x18microsoft_peering_config\x18\x08 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeeringConfig\x12\x1c\n\x14gateway_manager_etag\x18\t \x01(\t\x12\x66\n\x13ipv6_peering_config\x18\n \x01(\x0b\x32I.oak9.tython.azure.microsoft_network.Ipv6ExpressRouteCircuitPeeringConfig\x12\x0c\n\x04name\x18\x0b \x01(\t\"\xe0\x02\n\'ExpressRouteCircuitsPeeringsConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x1d\x65xpress_route_circuit_peering\x18\x03 \x01(\t\x12*\n\"peer_express_route_circuit_peering\x18\x04 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x05 \x01(\t\x12\x19\n\x11\x61uthorization_key\x18\x06 \x01(\t\x12h\n\x1eipv6_circuit_connection_config\x18\x07 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network.Ipv6CircuitConnectionConfig\"5\n\x1bIpv6CircuitConnectionConfig\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\t\"\x86\x06\n\x1c\x45xpressRouteCircuitsPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cpeering_type\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x10\n\x08peer_asn\x18\x05 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x06 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x07 \x01(\t\x12\x12\n\nshared_key\x18\x08 \x01(\t\x12\x0f\n\x07vlan_id\x18\t \x01(\x05\x12g\n\x18microsoft_peering_config\x18\n \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeeringConfig\x12L\n\x05stats\x18\x0b \x01(\x0b\x32=.oak9.tython.azure.microsoft_network.ExpressRouteCircuitStats\x12\x1c\n\x14gateway_manager_etag\x18\x0c \x01(\t\x12\x14\n\x0croute_filter\x18\r \x01(\t\x12\x66\n\x13ipv6_peering_config\x18\x0e \x01(\x0b\x32I.oak9.tython.azure.microsoft_network.Ipv6ExpressRouteCircuitPeeringConfig\x12 \n\x18\x65xpress_route_connection\x18\x0f \x01(\t\x12\x81\x01\n+express_route_circuits_peerings_connections\x18\x10 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network.ExpressRouteCircuitsPeeringsConnections\"k\n\"ExpressRouteCircuitsAuthorizations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xde\x07\n\x14\x45xpressRouteCircuits\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12Q\n\x04tags\x18\x04 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network.ExpressRouteCircuits.TagsEntry\x12H\n\x03sku\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_network.ExpressRouteCircuitSku\x12 \n\x18\x61llow_classic_operations\x18\x06 \x01(\x08\x12]\n\x0e\x61uthorizations\x18\x07 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitAuthorization\x12Q\n\x08peerings\x18\x08 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeering\x12\x1e\n\x16service_provider_notes\x18\t \x01(\t\x12v\n\x1bservice_provider_properties\x18\n \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network.ExpressRouteCircuitServiceProviderProperties\x12\x1a\n\x12\x65xpress_route_port\x18\x0b \x01(\t\x12\x19\n\x11\x62\x61ndwidth_in_gbps\x18\x0c \x01(\x01\x12\x1c\n\x14gateway_manager_etag\x18\r \x01(\t\x12j\n\x1f\x65xpress_route_circuits_peerings\x18\x0e \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.ExpressRouteCircuitsPeerings\x12v\n%express_route_circuits_authorizations\x18\x0f \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.ExpressRouteCircuitsAuthorizations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n,ExpressRouteCircuitServiceProviderProperties\x12\x1d\n\x15service_provider_name\x18\x01 \x01(\t\x12\x18\n\x10peering_location\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61ndwidth_in_mbps\x18\x03 \x01(\x05\"\xc7\x04\n\x1a\x45xpressRouteCircuitPeering\x12\x14\n\x0cpeering_type\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x10\n\x08peer_asn\x18\x03 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x04 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x05 \x01(\t\x12\x12\n\nshared_key\x18\x06 \x01(\t\x12\x0f\n\x07vlan_id\x18\x07 \x01(\x05\x12g\n\x18microsoft_peering_config\x18\x08 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeeringConfig\x12L\n\x05stats\x18\t \x01(\x0b\x32=.oak9.tython.azure.microsoft_network.ExpressRouteCircuitStats\x12\x1c\n\x14gateway_manager_etag\x18\n \x01(\t\x12\x14\n\x0croute_filter\x18\x0b \x01(\t\x12\x66\n\x13ipv6_peering_config\x18\x0c \x01(\x0b\x32I.oak9.tython.azure.microsoft_network.Ipv6ExpressRouteCircuitPeeringConfig\x12 \n\x18\x65xpress_route_connection\x18\r \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\"\x80\x02\n$Ipv6ExpressRouteCircuitPeeringConfig\x12#\n\x1bprimary_peer_address_prefix\x18\x01 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x02 \x01(\t\x12g\n\x18microsoft_peering_config\x18\x03 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network.ExpressRouteCircuitPeeringConfig\x12\x14\n\x0croute_filter\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\"\x84\x01\n\x18\x45xpressRouteCircuitStats\x12\x17\n\x0fprimarybytes_in\x18\x01 \x01(\x05\x12\x18\n\x10primarybytes_out\x18\x02 \x01(\x05\x12\x19\n\x11secondarybytes_in\x18\x03 \x01(\x05\x12\x1a\n\x12secondarybytes_out\x18\x04 \x01(\x05\"\xb0\x01\n ExpressRouteCircuitPeeringConfig\x12\"\n\x1a\x61\x64vertised_public_prefixes\x18\x01 \x03(\t\x12\x1e\n\x16\x61\x64vertised_communities\x18\x02 \x03(\t\x12\x13\n\x0blegacy_mode\x18\x03 \x01(\x05\x12\x14\n\x0c\x63ustomer_asn\x18\x04 \x01(\x05\x12\x1d\n\x15routing_registry_name\x18\x05 \x01(\t\"0\n ExpressRouteCircuitAuthorization\x12\x0c\n\x04name\x18\x01 \x01(\t\"D\n\x16\x45xpressRouteCircuitSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\"\xcd\x04\n\x12\x44scpConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12O\n\x04tags\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.DscpConfigurations.TagsEntry\x12\x10\n\x08markings\x18\x05 \x03(\x05\x12I\n\x10source_ip_ranges\x18\x06 \x03(\x0b\x32/.oak9.tython.azure.microsoft_network.QosIpRange\x12N\n\x15\x64\x65stination_ip_ranges\x18\x07 \x03(\x0b\x32/.oak9.tython.azure.microsoft_network.QosIpRange\x12M\n\x12source_port_ranges\x18\x08 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.QosPortRange\x12R\n\x17\x64\x65stination_port_ranges\x18\t \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_network.QosPortRange\x12\x10\n\x08protocol\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x0cQosPortRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\".\n\nQosIpRange\x12\x10\n\x08start_ip\x18\x01 \x01(\t\x12\x0e\n\x06\x65nd_ip\x18\x02 \x01(\t\"\xed\x01\n\x13\x44\x64osProtectionPlans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12P\n\x04tags\x18\x04 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network.DdosProtectionPlans.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x02\n\x12\x44\x64osCustomPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12O\n\x04tags\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.DdosCustomPolicies.TagsEntry\x12\x63\n\x18protocol_custom_settings\x18\x05 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.ProtocolCustomSettingsFormat\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x01\n\x1cProtocolCustomSettingsFormat\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x1d\n\x15trigger_rate_override\x18\x02 \x01(\t\x12\x1c\n\x14source_rate_override\x18\x03 \x01(\t\x12$\n\x1ctrigger_sensitivity_override\x18\x04 \x01(\t\"\xf2\x02\n\x10\x43ustomIpPrefixes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12M\n\x04tags\x18\x04 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.CustomIpPrefixes.TagsEntry\x12P\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.ExtendedLocation\x12\x0c\n\x04\x63idr\x18\x06 \x01(\t\x12\x1a\n\x12\x63ommissioned_state\x18\x07 \x01(\t\x12\r\n\x05zones\x18\x08 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xb5\x06\n\x0b\x43onnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12H\n\x04tags\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.Connections.TagsEntry\x12\x19\n\x11\x61uthorization_key\x18\x05 \x01(\t\x12 \n\x18virtual_network_gateway1\x18\x06 \x01(\t\x12 \n\x18virtual_network_gateway2\x18\x07 \x01(\t\x12\x1e\n\x16local_network_gateway2\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\t \x01(\t\x12\x1b\n\x13\x63onnection_protocol\x18\n \x01(\t\x12\x16\n\x0erouting_weight\x18\x0b \x01(\x05\x12\x1b\n\x13\x64pd_timeout_seconds\x18\x0c \x01(\x05\x12\x17\n\x0f\x63onnection_mode\x18\r \x01(\t\x12\x12\n\nshared_key\x18\x0e \x01(\t\x12\x0c\n\x04peer\x18\x0f \x01(\t\x12\x12\n\nenable_bgp\x18\x10 \x01(\x08\x12\"\n\x1ause_local_azure_ip_address\x18\x11 \x01(\x08\x12*\n\"use_policy_based_traffic_selectors\x18\x12 \x01(\x08\x12H\n\x0eipsec_policies\x18\x13 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_network.IpsecPolicy\x12]\n\x19traffic_selector_policies\x18\x14 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network.TrafficSelectorPolicy\x12$\n\x1c\x65xpress_route_gateway_bypass\x18\x15 \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n\x15TrafficSelectorPolicy\x12\x1c\n\x14local_address_ranges\x18\x01 \x03(\t\x12\x1d\n\x15remote_address_ranges\x18\x02 \x03(\t\"\xd2\x01\n\x0bIpsecPolicy\x12\x1c\n\x14sa_life_time_seconds\x18\x01 \x01(\x05\x12\x1e\n\x16sa_data_size_kilobytes\x18\x02 \x01(\x05\x12\x18\n\x10ipsec_encryption\x18\x03 \x01(\t\x12\x17\n\x0fipsec_integrity\x18\x04 \x01(\t\x12\x16\n\x0eike_encryption\x18\x05 \x01(\t\x12\x15\n\rike_integrity\x18\x06 \x01(\t\x12\x10\n\x08\x64h_group\x18\x07 \x01(\t\x12\x11\n\tpfs_group\x18\x08 \x01(\t\"\xcd\x02\n\x0c\x42\x61stionHosts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12I\n\x04tags\x18\x04 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.BastionHosts.TagsEntry\x12Z\n\x11ip_configurations\x18\x05 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network.BastionHostIPConfiguration\x12\x10\n\x08\x64ns_name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x1a\x42\x61stionHostIPConfiguration\x12\x0e\n\x06subnet\x18\x01 \x01(\t\x12\x19\n\x11public_ip_address\x18\x02 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x80\t\n\x0e\x41zureFirewalls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12K\n\x04tags\x18\x04 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.AzureFirewalls.TagsEntry\x12q\n\x1c\x61pplication_rule_collections\x18\x05 \x03(\x0b\x32K.oak9.tython.azure.microsoft_network.AzureFirewallApplicationRuleCollection\x12\x61\n\x14nat_rule_collections\x18\x06 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network.AzureFirewallNatRuleCollection\x12i\n\x18network_rule_collections\x18\x07 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network.AzureFirewallNetworkRuleCollection\x12\\\n\x11ip_configurations\x18\x08 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.AzureFirewallIPConfiguration\x12\x66\n\x1bmanagement_ip_configuration\x18\t \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network.AzureFirewallIPConfiguration\x12\x19\n\x11threat_intel_mode\x18\n \x01(\t\x12\x13\n\x0bvirtual_hub\x18\x0b \x01(\t\x12\x17\n\x0f\x66irewall_policy\x18\x0c \x01(\t\x12M\n\x10hub_ip_addresses\x18\r \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_network.HubIPAddresses\x12\x42\n\x03sku\x18\x0e \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_network.AzureFirewallSku\x12l\n\x15\x61\x64\x64itional_properties\x18\x0f \x03(\x0b\x32M.oak9.tython.azure.microsoft_network.AzureFirewalls.AdditionalPropertiesEntry\x12\r\n\x05zones\x18\x10 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x41zureFirewallSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"{\n\x0eHubIPAddresses\x12M\n\npublic_ips\x18\x01 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network.HubPublicIPAddresses\x12\x1a\n\x12private_ip_address\x18\x02 \x01(\t\"{\n\x14HubPublicIPAddresses\x12T\n\taddresses\x18\x01 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.AzureFirewallPublicIPAddress\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"/\n\x1c\x41zureFirewallPublicIPAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"W\n\x1c\x41zureFirewallIPConfiguration\x12\x0e\n\x06subnet\x18\x01 \x01(\t\x12\x19\n\x11public_ip_address\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xde\x01\n\"AzureFirewallNetworkRuleCollection\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12J\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_network.AzureFirewallRCAction\x12L\n\x05rules\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.AzureFirewallNetworkRule\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xf8\x01\n\x18\x41zureFirewallNetworkRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tprotocols\x18\x03 \x03(\t\x12\x18\n\x10source_addresses\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65stination_addresses\x18\x05 \x03(\t\x12\x19\n\x11\x64\x65stination_ports\x18\x06 \x03(\t\x12\x19\n\x11\x64\x65stination_fqdns\x18\x07 \x03(\t\x12\x18\n\x10source_ip_groups\x18\x08 \x03(\t\x12\x1d\n\x15\x64\x65stination_ip_groups\x18\t \x03(\t\"\xd9\x01\n\x1e\x41zureFirewallNatRuleCollection\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12M\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_network.AzureFirewallNatRCAction\x12H\n\x05rules\x18\x03 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network.AzureFirewallNatRule\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x88\x02\n\x14\x41zureFirewallNatRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10source_addresses\x18\x03 \x03(\t\x12\x1d\n\x15\x64\x65stination_addresses\x18\x04 \x03(\t\x12\x19\n\x11\x64\x65stination_ports\x18\x05 \x03(\t\x12\x11\n\tprotocols\x18\x06 \x03(\t\x12\x1a\n\x12translated_address\x18\x07 \x01(\t\x12\x17\n\x0ftranslated_port\x18\x08 \x01(\t\x12\x17\n\x0ftranslated_fqdn\x18\t \x01(\t\x12\x18\n\x10source_ip_groups\x18\n \x03(\t\"(\n\x18\x41zureFirewallNatRCAction\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xe6\x01\n&AzureFirewallApplicationRuleCollection\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12J\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_network.AzureFirewallRCAction\x12P\n\x05rules\x18\x03 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network.AzureFirewallApplicationRule\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xfc\x01\n\x1c\x41zureFirewallApplicationRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10source_addresses\x18\x03 \x03(\t\x12\\\n\tprotocols\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network.AzureFirewallApplicationRuleProtocol\x12\x14\n\x0ctarget_fqdns\x18\x05 \x03(\t\x12\x11\n\tfqdn_tags\x18\x06 \x03(\t\x12\x18\n\x10source_ip_groups\x18\x07 \x03(\t\"K\n$AzureFirewallApplicationRuleProtocol\x12\x15\n\rprotocol_type\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"%\n\x15\x41zureFirewallRCAction\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xf9\x01\n\x19\x41pplicationSecurityGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12V\n\x04tags\x18\x04 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network.ApplicationSecurityGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x04\n0ApplicationGatewayWebApplicationFirewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12m\n\x04tags\x18\x04 \x03(\x0b\x32_.oak9.tython.azure.microsoft_network.ApplicationGatewayWebApplicationFirewallPolicies.TagsEntry\x12L\n\x0fpolicy_settings\x18\x05 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_network.PolicySettings\x12[\n\x0c\x63ustom_rules\x18\x06 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network.WebApplicationFirewallCustomRule\x12R\n\rmanaged_rules\x18\x07 \x01(\x0b\x32;.oak9.tython.azure.microsoft_network.ManagedRulesDefinition\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb9\x01\n\x16ManagedRulesDefinition\x12O\n\nexclusions\x18\x01 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network.OwaspCrsExclusionEntry\x12N\n\x11managed_rule_sets\x18\x02 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_network.ManagedRuleSet\"\x9e\x01\n\x0eManagedRuleSet\x12\x15\n\rrule_set_type\x18\x01 \x01(\t\x12\x18\n\x10rule_set_version\x18\x02 \x01(\t\x12[\n\x14rule_group_overrides\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network.ManagedRuleGroupOverride\"|\n\x18ManagedRuleGroupOverride\x12\x17\n\x0frule_group_name\x18\x01 \x01(\t\x12G\n\x05rules\x18\x02 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network.ManagedRuleOverride\"5\n\x13ManagedRuleOverride\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"c\n\x16OwaspCrsExclusionEntry\x12\x16\n\x0ematch_variable\x18\x01 \x01(\t\x12\x1f\n\x17selector_match_operator\x18\x02 \x01(\t\x12\x10\n\x08selector\x18\x03 \x01(\t\"\xb4\x01\n WebApplicationFirewallCustomRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x11\n\trule_type\x18\x03 \x01(\t\x12M\n\x10match_conditions\x18\x04 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_network.MatchCondition\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\"\xb4\x01\n\x0eMatchCondition\x12K\n\x0fmatch_variables\x18\x01 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_network.MatchVariable\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x19\n\x11negation_conditon\x18\x03 \x01(\x08\x12\x14\n\x0cmatch_values\x18\x04 \x03(\t\x12\x12\n\ntransforms\x18\x05 \x03(\t\"8\n\rMatchVariable\x12\x15\n\rvariable_name\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\"\x8f\x01\n\x0ePolicySettings\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\x1a\n\x12request_body_check\x18\x03 \x01(\x08\x12#\n\x1bmax_request_body_size_in_kb\x18\x04 \x01(\x05\x12\x1f\n\x17\x66ile_upload_limit_in_mb\x18\x05 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VPNSITES_TAGSENTRY._options = None
  _VPNSITES_TAGSENTRY._serialized_options = b'8\001'
  _VPNSERVERCONFIGURATIONS_TAGSENTRY._options = None
  _VPNSERVERCONFIGURATIONS_TAGSENTRY._serialized_options = b'8\001'
  _VPNGATEWAYS_TAGSENTRY._options = None
  _VPNGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALWANS_TAGSENTRY._options = None
  _VIRTUALWANS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALROUTERS_TAGSENTRY._options = None
  _VIRTUALROUTERS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALNETWORKTAPS_TAGSENTRY._options = None
  _VIRTUALNETWORKTAPS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._options = None
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICIPADDRESS_TAGSENTRY._options = None
  _PUBLICIPADDRESS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALHUBS_TAGSENTRY._options = None
  _VIRTUALHUBS_TAGSENTRY._serialized_options = b'8\001'
  _SERVICEENDPOINTPOLICIES_TAGSENTRY._options = None
  _SERVICEENDPOINTPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _SECURITYPARTNERPROVIDERS_TAGSENTRY._options = None
  _SECURITYPARTNERPROVIDERS_TAGSENTRY._serialized_options = b'8\001'
  _ROUTEFILTERS_TAGSENTRY._options = None
  _ROUTEFILTERS_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICIPPREFIXES_TAGSENTRY._options = None
  _PUBLICIPPREFIXES_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICIPADDRESSES_TAGSENTRY._options = None
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_options = b'8\001'
  _P2SVPNGATEWAYS_TAGSENTRY._options = None
  _P2SVPNGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKWATCHERSFLOWLOGS_TAGSENTRY._options = None
  _NETWORKWATCHERSFLOWLOGS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._options = None
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKWATCHERS_TAGSENTRY._options = None
  _NETWORKWATCHERS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKVIRTUALAPPLIANCES_TAGSENTRY._options = None
  _NETWORKVIRTUALAPPLIANCES_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKPROFILES_TAGSENTRY._options = None
  _NETWORKPROFILES_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKINTERFACES_TAGSENTRY._options = None
  _NETWORKINTERFACES_TAGSENTRY._serialized_options = b'8\001'
  _NATGATEWAYS_TAGSENTRY._options = None
  _NATGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _LOCALNETWORKGATEWAYS_TAGSENTRY._options = None
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _IPGROUPS_TAGSENTRY._options = None
  _IPGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _IPALLOCATIONS_TAGSENTRY._options = None
  _IPALLOCATIONS_TAGSENTRY._serialized_options = b'8\001'
  _IPALLOCATIONS_ALLOCATIONTAGSENTRY._options = None
  _IPALLOCATIONS_ALLOCATIONTAGSENTRY._serialized_options = b'8\001'
  _EXPRESSROUTEPORTS_TAGSENTRY._options = None
  _EXPRESSROUTEPORTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _EXPRESSROUTEGATEWAYS_TAGSENTRY._options = None
  _EXPRESSROUTEGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._options = None
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _EXPRESSROUTECIRCUITS_TAGSENTRY._options = None
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_options = b'8\001'
  _DSCPCONFIGURATIONS_TAGSENTRY._options = None
  _DSCPCONFIGURATIONS_TAGSENTRY._serialized_options = b'8\001'
  _DDOSPROTECTIONPLANS_TAGSENTRY._options = None
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_options = b'8\001'
  _DDOSCUSTOMPOLICIES_TAGSENTRY._options = None
  _DDOSCUSTOMPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMIPPREFIXES_TAGSENTRY._options = None
  _CUSTOMIPPREFIXES_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTIONS_TAGSENTRY._options = None
  _CONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _BASTIONHOSTS_TAGSENTRY._options = None
  _BASTIONHOSTS_TAGSENTRY._serialized_options = b'8\001'
  _AZUREFIREWALLS_TAGSENTRY._options = None
  _AZUREFIREWALLS_TAGSENTRY._serialized_options = b'8\001'
  _AZUREFIREWALLS_ADDITIONALPROPERTIESENTRY._options = None
  _AZUREFIREWALLS_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._options = None
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._options = None
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK._serialized_start=98
  _MICROSOFT_NETWORK._serialized_end=3492
  _VPNSITES._serialized_start=3495
  _VPNSITES._serialized_end=4179
  _VPNSITES_TAGSENTRY._serialized_start=4136
  _VPNSITES_TAGSENTRY._serialized_end=4179
  _O365POLICYPROPERTIES._serialized_start=4181
  _O365POLICYPROPERTIES._serialized_end=4300
  _O365BREAKOUTCATEGORYPOLICIES._serialized_start=4302
  _O365BREAKOUTCATEGORYPOLICIES._serialized_end=4382
  _VPNSITELINK._serialized_start=4385
  _VPNSITELINK._serialized_end=4616
  _VPNLINKBGPSETTINGS._serialized_start=4618
  _VPNLINKBGPSETTINGS._serialized_end=4680
  _VPNLINKPROVIDERPROPERTIES._serialized_start=4682
  _VPNLINKPROVIDERPROPERTIES._serialized_end=4765
  _DEVICEPROPERTIES._serialized_start=4767
  _DEVICEPROPERTIES._serialized_end=4858
  _VPNSERVERCONFIGURATIONS._serialized_start=4861
  _VPNSERVERCONFIGURATIONS._serialized_end=5971
  _VPNSERVERCONFIGURATIONS_TAGSENTRY._serialized_start=4136
  _VPNSERVERCONFIGURATIONS_TAGSENTRY._serialized_end=4179
  _AADAUTHENTICATIONPARAMETERS._serialized_start=5973
  _AADAUTHENTICATIONPARAMETERS._serialized_end=6064
  _VPNSERVERCONFIGRADIUSCLIENTROOTCERTIFICATE._serialized_start=6066
  _VPNSERVERCONFIGRADIUSCLIENTROOTCERTIFICATE._serialized_end=6144
  _VPNSERVERCONFIGRADIUSSERVERROOTCERTIFICATE._serialized_start=6146
  _VPNSERVERCONFIGRADIUSSERVERROOTCERTIFICATE._serialized_end=6230
  _VPNSERVERCONFIGVPNCLIENTREVOKEDCERTIFICATE._serialized_start=6232
  _VPNSERVERCONFIGVPNCLIENTREVOKEDCERTIFICATE._serialized_end=6310
  _VPNSERVERCONFIGVPNCLIENTROOTCERTIFICATE._serialized_start=6312
  _VPNSERVERCONFIGVPNCLIENTROOTCERTIFICATE._serialized_end=6393
  _VPNGATEWAYSVPNCONNECTIONS._serialized_start=6396
  _VPNGATEWAYSVPNCONNECTIONS._serialized_end=7200
  _VPNGATEWAYSNATRULES._serialized_start=7203
  _VPNGATEWAYSNATRULES._serialized_end=7518
  _VPNGATEWAYS._serialized_start=7521
  _VPNGATEWAYS._serialized_end=8145
  _VPNGATEWAYS_TAGSENTRY._serialized_start=4136
  _VPNGATEWAYS_TAGSENTRY._serialized_end=4179
  _VPNGATEWAYNATRULE._serialized_start=8148
  _VPNGATEWAYNATRULE._serialized_end=8404
  _VPNNATRULEMAPPING._serialized_start=8406
  _VPNNATRULEMAPPING._serialized_end=8448
  _VPNCONNECTION._serialized_start=8451
  _VPNCONNECTION._serialized_end=9186
  _VPNSITELINKCONNECTION._serialized_start=9189
  _VPNSITELINKCONNECTION._serialized_end=9679
  _VIRTUALWANS._serialized_start=9682
  _VIRTUALWANS._serialized_end=10068
  _VIRTUALWANS_TAGSENTRY._serialized_start=4136
  _VIRTUALWANS_TAGSENTRY._serialized_end=4179
  _VIRTUALROUTERSPEERINGS._serialized_start=10071
  _VIRTUALROUTERSPEERINGS._serialized_end=10201
  _VIRTUALROUTERS._serialized_start=10204
  _VIRTUALROUTERS._serialized_end=10629
  _VIRTUALROUTERS_TAGSENTRY._serialized_start=4136
  _VIRTUALROUTERS_TAGSENTRY._serialized_end=4179
  _VIRTUALNETWORKTAPS._serialized_start=10632
  _VIRTUALNETWORKTAPS._serialized_end=11011
  _VIRTUALNETWORKTAPS_TAGSENTRY._serialized_start=4136
  _VIRTUALNETWORKTAPS_TAGSENTRY._serialized_end=4179
  _VIRTUALNETWORKGATEWAYS._serialized_start=11014
  _VIRTUALNETWORKGATEWAYS._serialized_end=12030
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_start=4136
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_end=4179
  _VPNCLIENTCONFIGURATION._serialized_start=12033
  _VPNCLIENTCONFIGURATION._serialized_end=12696
  _RADIUSSERVER._serialized_start=12698
  _RADIUSSERVER._serialized_end=12802
  _VPNCLIENTREVOKEDCERTIFICATE._serialized_start=12804
  _VPNCLIENTREVOKEDCERTIFICATE._serialized_end=12867
  _VPNCLIENTROOTCERTIFICATE._serialized_start=12869
  _VPNCLIENTROOTCERTIFICATE._serialized_end=12935
  _VIRTUALNETWORKGATEWAYSKU._serialized_start=12937
  _VIRTUALNETWORKGATEWAYSKU._serialized_end=12991
  _VIRTUALNETWORKGATEWAYIPCONFIGURATION._serialized_start=12994
  _VIRTUALNETWORKGATEWAYIPCONFIGURATION._serialized_end=13127
  _VIRTUALHUBSROUTETABLES._serialized_start=13130
  _VIRTUALHUBSROUTETABLES._serialized_end=13327
  _VIRTUALHUBSIPCONFIGURATIONS._serialized_start=13330
  _VIRTUALHUBSIPCONFIGURATIONS._serialized_end=13638
  _PUBLICIPADDRESS._serialized_start=13641
  _PUBLICIPADDRESS._serialized_end=14339
  _PUBLICIPADDRESS_TAGSENTRY._serialized_start=4136
  _PUBLICIPADDRESS_TAGSENTRY._serialized_end=4179
  _SUBNET._serialized_start=14342
  _SUBNET._serialized_end=14804
  _DELEGATION._serialized_start=14806
  _DELEGATION._serialized_end=14854
  _SERVICEENDPOINTPROPERTIESFORMAT._serialized_start=14856
  _SERVICEENDPOINTPROPERTIESFORMAT._serialized_end=14925
  _VIRTUALHUBSHUBVIRTUALNETWORKCONNECTIONS._serialized_start=14928
  _VIRTUALHUBSHUBVIRTUALNETWORKCONNECTIONS._serialized_end=15290
  _VIRTUALHUBSHUBROUTETABLES._serialized_start=15293
  _VIRTUALHUBSHUBROUTETABLES._serialized_end=15470
  _HUBROUTE._serialized_start=15472
  _HUBROUTE._serialized_end=15585
  _VIRTUALHUBSBGPCONNECTIONS._serialized_start=15588
  _VIRTUALHUBSBGPCONNECTIONS._serialized_end=15721
  _VIRTUALHUBS._serialized_start=15724
  _VIRTUALHUBS._serialized_end=17009
  _VIRTUALHUBS_TAGSENTRY._serialized_start=4136
  _VIRTUALHUBS_TAGSENTRY._serialized_end=4179
  _VIRTUALHUBROUTETABLEV2._serialized_start=17012
  _VIRTUALHUBROUTETABLEV2._serialized_end=17152
  _VIRTUALHUBROUTEV2._serialized_start=17154
  _VIRTUALHUBROUTEV2._serialized_end=17263
  _VIRTUALHUBROUTETABLE._serialized_start=17265
  _VIRTUALHUBROUTETABLE._serialized_end=17357
  _VIRTUALHUBROUTE._serialized_start=17359
  _VIRTUALHUBROUTE._serialized_end=17431
  _SERVICEENDPOINTPOLICIESSERVICEENDPOINTPOLICYDEFINITIONS._serialized_start=17434
  _SERVICEENDPOINTPOLICIESSERVICEENDPOINTPOLICYDEFINITIONS._serialized_end=17627
  _SERVICEENDPOINTPOLICIES._serialized_start=17630
  _SERVICEENDPOINTPOLICIES._serialized_end=17990
  _SERVICEENDPOINTPOLICIES_TAGSENTRY._serialized_start=4136
  _SERVICEENDPOINTPOLICIES_TAGSENTRY._serialized_end=4179
  _SERVICEENDPOINTPOLICYDEFINITION._serialized_start=17992
  _SERVICEENDPOINTPOLICYDEFINITION._serialized_end=18104
  _SECURITYPARTNERPROVIDERS._serialized_start=18107
  _SECURITYPARTNERPROVIDERS._serialized_end=18407
  _SECURITYPARTNERPROVIDERS_TAGSENTRY._serialized_start=4136
  _SECURITYPARTNERPROVIDERS_TAGSENTRY._serialized_end=4179
  _ROUTEFILTERSROUTEFILTERRULES._serialized_start=18410
  _ROUTEFILTERSROUTEFILTERRULES._serialized_end=18598
  _ROUTEFILTERS._serialized_start=18601
  _ROUTEFILTERS._serialized_end=18893
  _ROUTEFILTERS_TAGSENTRY._serialized_start=4136
  _ROUTEFILTERS_TAGSENTRY._serialized_end=4179
  _ROUTEFILTERRULE._serialized_start=18895
  _ROUTEFILTERRULE._serialized_end=19013
  _PUBLICIPPREFIXES._serialized_start=19016
  _PUBLICIPPREFIXES._serialized_end=19558
  _PUBLICIPPREFIXES_TAGSENTRY._serialized_start=4136
  _PUBLICIPPREFIXES_TAGSENTRY._serialized_end=4179
  _PUBLICIPPREFIXSKU._serialized_start=19560
  _PUBLICIPPREFIXSKU._serialized_end=19607
  _PUBLICIPADDRESSES._serialized_start=19610
  _PUBLICIPADDRESSES._serialized_end=20383
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_start=4136
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_end=4179
  _IPTAG._serialized_start=20385
  _IPTAG._serialized_end=20426
  _DDOSSETTINGS._serialized_start=20428
  _DDOSSETTINGS._serialized_end=20521
  _PUBLICIPADDRESSDNSSETTINGS._serialized_start=20523
  _PUBLICIPADDRESSDNSSETTINGS._serialized_end=20614
  _PUBLICIPADDRESSSKU._serialized_start=20616
  _PUBLICIPADDRESSSKU._serialized_end=20664
  _P2SVPNGATEWAYS._serialized_start=20667
  _P2SVPNGATEWAYS._serialized_end=21154
  _P2SVPNGATEWAYS_TAGSENTRY._serialized_start=4136
  _P2SVPNGATEWAYS_TAGSENTRY._serialized_end=4179
  _P2SCONNECTIONCONFIGURATION._serialized_start=21157
  _P2SCONNECTIONCONFIGURATION._serialized_end=21407
  _NETWORKWATCHERSPACKETCAPTURES._serialized_start=21410
  _NETWORKWATCHERSPACKETCAPTURES._serialized_end=21797
  _PACKETCAPTUREFILTER._serialized_start=21800
  _PACKETCAPTUREFILTER._serialized_end=21933
  _PACKETCAPTURESTORAGELOCATION._serialized_start=21935
  _PACKETCAPTURESTORAGELOCATION._serialized_end=22026
  _NETWORKWATCHERSFLOWLOGS._serialized_start=22029
  _NETWORKWATCHERSFLOWLOGS._serialized_end=22610
  _NETWORKWATCHERSFLOWLOGS_TAGSENTRY._serialized_start=4136
  _NETWORKWATCHERSFLOWLOGS_TAGSENTRY._serialized_end=4179
  _TRAFFICANALYTICSPROPERTIES._serialized_start=22613
  _TRAFFICANALYTICSPROPERTIES._serialized_end=22774
  _TRAFFICANALYTICSCONFIGURATIONPROPERTIES._serialized_start=22777
  _TRAFFICANALYTICSCONFIGURATIONPROPERTIES._serialized_end=22950
  _FLOWLOGFORMATPARAMETERS._serialized_start=22952
  _FLOWLOGFORMATPARAMETERS._serialized_end=23008
  _RETENTIONPOLICYPARAMETERS._serialized_start=23010
  _RETENTIONPOLICYPARAMETERS._serialized_end=23068
  _NETWORKWATCHERSCONNECTIONMONITORS._serialized_start=23071
  _NETWORKWATCHERSCONNECTIONMONITORS._serialized_end=23927
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_start=4136
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_end=4179
  _CONNECTIONMONITOROUTPUT._serialized_start=23930
  _CONNECTIONMONITOROUTPUT._serialized_end=24070
  _CONNECTIONMONITORWORKSPACESETTINGS._serialized_start=24072
  _CONNECTIONMONITORWORKSPACESETTINGS._serialized_end=24139
  _CONNECTIONMONITORTESTGROUP._serialized_start=24141
  _CONNECTIONMONITORTESTGROUP._serialized_end=24268
  _CONNECTIONMONITORTESTCONFIGURATION._serialized_start=24271
  _CONNECTIONMONITORTESTCONFIGURATION._serialized_end=24797
  _CONNECTIONMONITORSUCCESSTHRESHOLD._serialized_start=24799
  _CONNECTIONMONITORSUCCESSTHRESHOLD._serialized_end=24893
  _CONNECTIONMONITORICMPCONFIGURATION._serialized_start=24895
  _CONNECTIONMONITORICMPCONFIGURATION._serialized_end=24960
  _CONNECTIONMONITORTCPCONFIGURATION._serialized_start=24962
  _CONNECTIONMONITORTCPCONFIGURATION._serialized_end=25075
  _CONNECTIONMONITORHTTPCONFIGURATION._serialized_start=25078
  _CONNECTIONMONITORHTTPCONFIGURATION._serialized_end=25289
  _HTTPHEADER._serialized_start=25291
  _HTTPHEADER._serialized_end=25332
  _CONNECTIONMONITORENDPOINT._serialized_start=25335
  _CONNECTIONMONITORENDPOINT._serialized_end=25622
  _CONNECTIONMONITORENDPOINTSCOPE._serialized_start=25625
  _CONNECTIONMONITORENDPOINTSCOPE._serialized_end=25837
  _CONNECTIONMONITORENDPOINTSCOPEITEM._serialized_start=25839
  _CONNECTIONMONITORENDPOINTSCOPEITEM._serialized_end=25892
  _CONNECTIONMONITORENDPOINTFILTER._serialized_start=25895
  _CONNECTIONMONITORENDPOINTFILTER._serialized_end=26031
  _CONNECTIONMONITORENDPOINTFILTERITEM._serialized_start=26033
  _CONNECTIONMONITORENDPOINTFILTERITEM._serialized_end=26101
  _CONNECTIONMONITORDESTINATION._serialized_start=26103
  _CONNECTIONMONITORDESTINATION._serialized_end=26185
  _CONNECTIONMONITORSOURCE._serialized_start=26187
  _CONNECTIONMONITORSOURCE._serialized_end=26247
  _NETWORKWATCHERS._serialized_start=26250
  _NETWORKWATCHERS._serialized_end=26805
  _NETWORKWATCHERS_TAGSENTRY._serialized_start=4136
  _NETWORKWATCHERS_TAGSENTRY._serialized_end=4179
  _NETWORKVIRTUALAPPLIANCESVIRTUALAPPLIANCESITES._serialized_start=26808
  _NETWORKVIRTUALAPPLIANCESVIRTUALAPPLIANCESITES._serialized_end=27035
  _OFFICE365POLICYPROPERTIES._serialized_start=27037
  _OFFICE365POLICYPROPERTIES._serialized_end=27157
  _BREAKOUTCATEGORYPOLICIES._serialized_start=27159
  _BREAKOUTCATEGORYPOLICIES._serialized_end=27235
  _NETWORKVIRTUALAPPLIANCESINBOUNDSECURITYRULES._serialized_start=27238
  _NETWORKVIRTUALAPPLIANCESINBOUNDSECURITYRULES._serialized_end=27429
  _INBOUNDSECURITYRULES._serialized_start=27431
  _INBOUNDSECURITYRULES._serialized_end=27534
  _NETWORKVIRTUALAPPLIANCES._serialized_start=27537
  _NETWORKVIRTUALAPPLIANCES._serialized_end=28402
  _NETWORKVIRTUALAPPLIANCES_TAGSENTRY._serialized_start=4136
  _NETWORKVIRTUALAPPLIANCES_TAGSENTRY._serialized_end=4179
  _VIRTUALAPPLIANCESKUPROPERTIES._serialized_start=28404
  _VIRTUALAPPLIANCESKUPROPERTIES._serialized_end=28509
  _NETWORKPROFILES._serialized_start=28512
  _NETWORKPROFILES._serialized_end=28870
  _NETWORKPROFILES_TAGSENTRY._serialized_start=4136
  _NETWORKPROFILES_TAGSENTRY._serialized_end=4179
  _CONTAINERNETWORKINTERFACECONFIGURATION._serialized_start=28873
  _CONTAINERNETWORKINTERFACECONFIGURATION._serialized_end=29053
  _IPCONFIGURATIONPROFILE._serialized_start=29055
  _IPCONFIGURATIONPROFILE._serialized_end=29109
  _NETWORKINTERFACESTAPCONFIGURATIONS._serialized_start=29112
  _NETWORKINTERFACESTAPCONFIGURATIONS._serialized_end=29248
  _NETWORKINTERFACES._serialized_start=29251
  _NETWORKINTERFACES._serialized_end=29972
  _NETWORKINTERFACES_TAGSENTRY._serialized_start=4136
  _NETWORKINTERFACES_TAGSENTRY._serialized_end=4179
  _NETWORKINTERFACEDNSSETTINGS._serialized_start=29974
  _NETWORKINTERFACEDNSSETTINGS._serialized_end=30057
  _NETWORKINTERFACEIPCONFIGURATION._serialized_start=30060
  _NETWORKINTERFACEIPCONFIGURATION._serialized_end=30473
  _NATGATEWAYS._serialized_start=30476
  _NATGATEWAYS._serialized_end=30867
  _NATGATEWAYS_TAGSENTRY._serialized_start=4136
  _NATGATEWAYS_TAGSENTRY._serialized_end=4179
  _NATGATEWAYSKU._serialized_start=30869
  _NATGATEWAYSKU._serialized_end=30898
  _LOCALNETWORKGATEWAYS._serialized_start=30901
  _LOCALNETWORKGATEWAYS._serialized_end=31342
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_start=4136
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_end=4179
  _BGPSETTINGS._serialized_start=31345
  _BGPSETTINGS._serialized_end=31523
  _IPCONFIGURATIONBGPPEERINGADDRESS._serialized_start=31525
  _IPCONFIGURATIONBGPPEERINGADDRESS._serialized_end=31620
  _ADDRESSSPACE._serialized_start=31622
  _ADDRESSSPACE._serialized_end=31662
  _IPGROUPS._serialized_start=31665
  _IPGROUPS._serialized_end=31902
  _IPGROUPS_TAGSENTRY._serialized_start=4136
  _IPGROUPS_TAGSENTRY._serialized_end=4179
  _IPALLOCATIONS._serialized_start=31905
  _IPALLOCATIONS._serialized_end=32384
  _IPALLOCATIONS_TAGSENTRY._serialized_start=4136
  _IPALLOCATIONS_TAGSENTRY._serialized_end=4179
  _IPALLOCATIONS_ALLOCATIONTAGSENTRY._serialized_start=32331
  _IPALLOCATIONS_ALLOCATIONTAGSENTRY._serialized_end=32384
  _EXPRESSROUTEPORTS._serialized_start=32387
  _EXPRESSROUTEPORTS._serialized_end=32845
  _EXPRESSROUTEPORTS_TAGSENTRY._serialized_start=4136
  _EXPRESSROUTEPORTS_TAGSENTRY._serialized_end=4179
  _MANAGEDSERVICEIDENTITY._serialized_start=32848
  _MANAGEDSERVICEIDENTITY._serialized_end=33072
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=33011
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=33072
  _EXPRESSROUTELINK._serialized_start=33075
  _EXPRESSROUTELINK._serialized_end=33219
  _EXPRESSROUTELINKMACSECCONFIG._serialized_start=33221
  _EXPRESSROUTELINKMACSECCONFIG._serialized_end=33348
  _EXPRESSROUTEGATEWAYSEXPRESSROUTECONNECTIONS._serialized_start=33351
  _EXPRESSROUTEGATEWAYSEXPRESSROUTECONNECTIONS._serialized_end=33719
  _ROUTINGCONFIGURATION._serialized_start=33722
  _ROUTINGCONFIGURATION._serialized_end=33937
  _VNETROUTE._serialized_start=33939
  _VNETROUTE._serialized_end=34023
  _STATICROUTE._serialized_start=34025
  _STATICROUTE._serialized_end=34107
  _PROPAGATEDROUTETABLE._serialized_start=34109
  _PROPAGATEDROUTETABLE._serialized_end=34160
  _EXPRESSROUTEGATEWAYS._serialized_start=34163
  _EXPRESSROUTEGATEWAYS._serialized_end=34688
  _EXPRESSROUTEGATEWAYS_TAGSENTRY._serialized_start=4136
  _EXPRESSROUTEGATEWAYS_TAGSENTRY._serialized_end=4179
  _EXPRESSROUTEGATEWAYPROPERTIESAUTOSCALECONFIGURATION._serialized_start=34691
  _EXPRESSROUTEGATEWAYPROPERTIESAUTOSCALECONFIGURATION._serialized_end=34856
  _EXPRESSROUTEGATEWAYPROPERTIESAUTOSCALECONFIGURATIONBOUNDS._serialized_start=34858
  _EXPRESSROUTEGATEWAYPROPERTIESAUTOSCALECONFIGURATIONBOUNDS._serialized_end=34943
  _EXPRESSROUTECROSSCONNECTIONSPEERINGS._serialized_start=34946
  _EXPRESSROUTECROSSCONNECTIONSPEERINGS._serialized_end=35462
  _EXPRESSROUTECROSSCONNECTIONS._serialized_start=35465
  _EXPRESSROUTECROSSCONNECTIONS._serialized_end=36044
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_start=4136
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_end=4179
  _EXPRESSROUTECROSSCONNECTIONPEERING._serialized_start=36047
  _EXPRESSROUTECROSSCONNECTIONPEERING._serialized_end=36504
  _EXPRESSROUTECIRCUITSPEERINGSCONNECTIONS._serialized_start=36507
  _EXPRESSROUTECIRCUITSPEERINGSCONNECTIONS._serialized_end=36859
  _IPV6CIRCUITCONNECTIONCONFIG._serialized_start=36861
  _IPV6CIRCUITCONNECTIONCONFIG._serialized_end=36914
  _EXPRESSROUTECIRCUITSPEERINGS._serialized_start=36917
  _EXPRESSROUTECIRCUITSPEERINGS._serialized_end=37691
  _EXPRESSROUTECIRCUITSAUTHORIZATIONS._serialized_start=37693
  _EXPRESSROUTECIRCUITSAUTHORIZATIONS._serialized_end=37800
  _EXPRESSROUTECIRCUITS._serialized_start=37803
  _EXPRESSROUTECIRCUITS._serialized_end=38793
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_start=4136
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_end=4179
  _EXPRESSROUTECIRCUITSERVICEPROVIDERPROPERTIES._serialized_start=38796
  _EXPRESSROUTECIRCUITSERVICEPROVIDERPROPERTIES._serialized_end=38926
  _EXPRESSROUTECIRCUITPEERING._serialized_start=38929
  _EXPRESSROUTECIRCUITPEERING._serialized_end=39512
  _IPV6EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_start=39515
  _IPV6EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_end=39771
  _EXPRESSROUTECIRCUITSTATS._serialized_start=39774
  _EXPRESSROUTECIRCUITSTATS._serialized_end=39906
  _EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_start=39909
  _EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_end=40085
  _EXPRESSROUTECIRCUITAUTHORIZATION._serialized_start=40087
  _EXPRESSROUTECIRCUITAUTHORIZATION._serialized_end=40135
  _EXPRESSROUTECIRCUITSKU._serialized_start=40137
  _EXPRESSROUTECIRCUITSKU._serialized_end=40205
  _DSCPCONFIGURATIONS._serialized_start=40208
  _DSCPCONFIGURATIONS._serialized_end=40797
  _DSCPCONFIGURATIONS_TAGSENTRY._serialized_start=4136
  _DSCPCONFIGURATIONS_TAGSENTRY._serialized_end=4179
  _QOSPORTRANGE._serialized_start=40799
  _QOSPORTRANGE._serialized_end=40841
  _QOSIPRANGE._serialized_start=40843
  _QOSIPRANGE._serialized_end=40889
  _DDOSPROTECTIONPLANS._serialized_start=40892
  _DDOSPROTECTIONPLANS._serialized_end=41129
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_start=4136
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_end=4179
  _DDOSCUSTOMPOLICIES._serialized_start=41132
  _DDOSCUSTOMPOLICIES._serialized_end=41468
  _DDOSCUSTOMPOLICIES_TAGSENTRY._serialized_start=4136
  _DDOSCUSTOMPOLICIES_TAGSENTRY._serialized_end=4179
  _PROTOCOLCUSTOMSETTINGSFORMAT._serialized_start=41471
  _PROTOCOLCUSTOMSETTINGSFORMAT._serialized_end=41618
  _CUSTOMIPPREFIXES._serialized_start=41621
  _CUSTOMIPPREFIXES._serialized_end=41991
  _CUSTOMIPPREFIXES_TAGSENTRY._serialized_start=4136
  _CUSTOMIPPREFIXES_TAGSENTRY._serialized_end=4179
  _EXTENDEDLOCATION._serialized_start=41993
  _EXTENDEDLOCATION._serialized_end=42039
  _CONNECTIONS._serialized_start=42042
  _CONNECTIONS._serialized_end=42863
  _CONNECTIONS_TAGSENTRY._serialized_start=4136
  _CONNECTIONS_TAGSENTRY._serialized_end=4179
  _TRAFFICSELECTORPOLICY._serialized_start=42865
  _TRAFFICSELECTORPOLICY._serialized_end=42949
  _IPSECPOLICY._serialized_start=42952
  _IPSECPOLICY._serialized_end=43162
  _BASTIONHOSTS._serialized_start=43165
  _BASTIONHOSTS._serialized_end=43498
  _BASTIONHOSTS_TAGSENTRY._serialized_start=4136
  _BASTIONHOSTS_TAGSENTRY._serialized_end=4179
  _BASTIONHOSTIPCONFIGURATION._serialized_start=43500
  _BASTIONHOSTIPCONFIGURATION._serialized_end=43623
  _AZUREFIREWALLS._serialized_start=43626
  _AZUREFIREWALLS._serialized_end=44778
  _AZUREFIREWALLS_TAGSENTRY._serialized_start=4136
  _AZUREFIREWALLS_TAGSENTRY._serialized_end=4179
  _AZUREFIREWALLS_ADDITIONALPROPERTIESENTRY._serialized_start=44719
  _AZUREFIREWALLS_ADDITIONALPROPERTIESENTRY._serialized_end=44778
  _AZUREFIREWALLSKU._serialized_start=44780
  _AZUREFIREWALLSKU._serialized_end=44826
  _HUBIPADDRESSES._serialized_start=44828
  _HUBIPADDRESSES._serialized_end=44951
  _HUBPUBLICIPADDRESSES._serialized_start=44953
  _HUBPUBLICIPADDRESSES._serialized_end=45076
  _AZUREFIREWALLPUBLICIPADDRESS._serialized_start=45078
  _AZUREFIREWALLPUBLICIPADDRESS._serialized_end=45125
  _AZUREFIREWALLIPCONFIGURATION._serialized_start=45127
  _AZUREFIREWALLIPCONFIGURATION._serialized_end=45214
  _AZUREFIREWALLNETWORKRULECOLLECTION._serialized_start=45217
  _AZUREFIREWALLNETWORKRULECOLLECTION._serialized_end=45439
  _AZUREFIREWALLNETWORKRULE._serialized_start=45442
  _AZUREFIREWALLNETWORKRULE._serialized_end=45690
  _AZUREFIREWALLNATRULECOLLECTION._serialized_start=45693
  _AZUREFIREWALLNATRULECOLLECTION._serialized_end=45910
  _AZUREFIREWALLNATRULE._serialized_start=45913
  _AZUREFIREWALLNATRULE._serialized_end=46177
  _AZUREFIREWALLNATRCACTION._serialized_start=46179
  _AZUREFIREWALLNATRCACTION._serialized_end=46219
  _AZUREFIREWALLAPPLICATIONRULECOLLECTION._serialized_start=46222
  _AZUREFIREWALLAPPLICATIONRULECOLLECTION._serialized_end=46452
  _AZUREFIREWALLAPPLICATIONRULE._serialized_start=46455
  _AZUREFIREWALLAPPLICATIONRULE._serialized_end=46707
  _AZUREFIREWALLAPPLICATIONRULEPROTOCOL._serialized_start=46709
  _AZUREFIREWALLAPPLICATIONRULEPROTOCOL._serialized_end=46784
  _AZUREFIREWALLRCACTION._serialized_start=46786
  _AZUREFIREWALLRCACTION._serialized_end=46823
  _APPLICATIONSECURITYGROUPS._serialized_start=46826
  _APPLICATIONSECURITYGROUPS._serialized_end=47075
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_start=4136
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_end=4179
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES._serialized_start=47078
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES._serialized_end=47628
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_start=4136
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_end=4179
  _MANAGEDRULESDEFINITION._serialized_start=47631
  _MANAGEDRULESDEFINITION._serialized_end=47816
  _MANAGEDRULESET._serialized_start=47819
  _MANAGEDRULESET._serialized_end=47977
  _MANAGEDRULEGROUPOVERRIDE._serialized_start=47979
  _MANAGEDRULEGROUPOVERRIDE._serialized_end=48103
  _MANAGEDRULEOVERRIDE._serialized_start=48105
  _MANAGEDRULEOVERRIDE._serialized_end=48158
  _OWASPCRSEXCLUSIONENTRY._serialized_start=48160
  _OWASPCRSEXCLUSIONENTRY._serialized_end=48259
  _WEBAPPLICATIONFIREWALLCUSTOMRULE._serialized_start=48262
  _WEBAPPLICATIONFIREWALLCUSTOMRULE._serialized_end=48442
  _MATCHCONDITION._serialized_start=48445
  _MATCHCONDITION._serialized_end=48625
  _MATCHVARIABLE._serialized_start=48627
  _MATCHVARIABLE._serialized_end=48683
  _POLICYSETTINGS._serialized_start=48686
  _POLICYSETTINGS._serialized_end=48829
# @@protoc_insertion_point(module_scope)
